==> openjdk-11_11.0.25~5ea.orig.tar.xz: openjdk-11-11.0.25~5ea/test/hotspot/jtreg/serviceability/jdwp/JdwpChannel.java <==
/*
 * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import java.io.IOException;
import java.io.InputStream;
import java.net.Socket;
import java.util.Arrays;

/**
 * JDWP socket transport
 */
public class JdwpChannel {

    private Socket sock;

    public void connect() throws IOException {
        sock = new Socket("localhost", DebuggeeLauncher.getJdwpPort());
        handshake();
    }

    /**
     * Sends JDWP handshake and verifies the reply
     * @throws IOException
     */
    private void handshake() throws IOException {
        final byte[] HANDSHAKE = "JDWP-Handshake".getBytes();
        sock.getOutputStream().write(HANDSHAKE, 0, HANDSHAKE.length);

        byte[] reply = new byte[14];
        sock.getInputStream().read(reply, 0, 14);
        if (!Arrays.equals(HANDSHAKE, reply)) {
            throw new RuntimeException("Error during handshake. Reply was: " + new String(reply) + " expected " + new String(HANDSHAKE));
        }
    }

    public void disconnect() {
        try {
            sock.close();
        } catch (IOException x) {
        }
    }

    public void write(byte[] data, int length) throws IOException {
        sock.getOutputStream().write(data, 0, length);
    }

    public InputStream getInputStream() throws IOException {
        return sock.getInputStream();
    }

}

==> openjdk-25_25~16ea.orig.tar.xz: openjdk-25-25~16ea/test/hotspot/jtreg/serviceability/jdwp/JdwpChannel.java <==
/*
 * Copyright (c) 2016, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import java.io.IOException;
import java.io.InputStream;
import java.net.Socket;
import java.util.Arrays;

/**
 * JDWP socket transport
 */
public class JdwpChannel {

    private Socket sock;

    public void connect(int jdwpPort) throws IOException {
        sock = new Socket("localhost", jdwpPort);
        handshake();
    }

    /**
     * Sends JDWP handshake and verifies the reply
     * @throws IOException
     */
    private void handshake() throws IOException {
        final byte[] HANDSHAKE = "JDWP-Handshake".getBytes();
        sock.getOutputStream().write(HANDSHAKE, 0, HANDSHAKE.length);

        byte[] reply = new byte[14];
        sock.getInputStream().read(reply, 0, 14);
        if (!Arrays.equals(HANDSHAKE, reply)) {
            throw new RuntimeException("Error during handshake. Reply was: " + new String(reply) + " expected " + new String(HANDSHAKE));
        }
    }

    public void disconnect() {
        try {
            sock.close();
        } catch (IOException x) {
        }
    }

    public void write(byte[] data, int length) throws IOException {
        sock.getOutputStream().write(data, 0, length);
    }

    public InputStream getInputStream() throws IOException {
        return sock.getInputStream();
    }

}
